@@ -39,7 +39,7 @@ from sphinx_gallery.sorting import ExplicitOrder
 from sunpy_sphinx_theme import PNG_ICON
 
 from astropy.utils.exceptions import AstropyDeprecationWarning
-
+from astropy.io.fits.verify import VerifyWarning
 import sunpy
 from sunpy.util.exceptions import SunpyDeprecationWarning, SunpyPendingDeprecationWarning
 
@@ -68,11 +68,16 @@ import doctest
 
 REMOTE_DATA = doctest.register_optionflag('REMOTE_DATA')
 
-# We want to make sure all the following warnings fail the build
-warnings.filterwarnings("error", category=SunpyDeprecationWarning)
-warnings.filterwarnings("error", category=SunpyPendingDeprecationWarning)
-warnings.filterwarnings("error", category=MatplotlibDeprecationWarning)
-warnings.filterwarnings("error", category=AstropyDeprecationWarning)
+# We want to make sure all the following warnings fail the build on CI but not
+# when actually building docs on RTD.
+if not on_rtd:
+    warnings.filterwarnings("error", category=SunpyDeprecationWarning)
+    warnings.filterwarnings("error", category=SunpyPendingDeprecationWarning)
+    warnings.filterwarnings("error", category=MatplotlibDeprecationWarning)
+    warnings.filterwarnings("error", category=AstropyDeprecationWarning)
+# Raised all by the sample data now and astropy 7,
+# so we want to prevent this failing any of the builds
+warnings.filterwarnings("ignore", category=VerifyWarning)
 
 # -- SunPy Sample Data and Config ----------------------------------------------
 
@@ -264,22 +269,31 @@ hoverxref_role_types = {
 # a list of builtin themes.
 html_theme = "sunpy"
 
+# Render inheritance diagrams in SVG
+graphviz_output_format = "svg"
+
+graphviz_dot_args = [
+    "-Nfontsize=10",
+    "-Nfontname=Helvetica Neue, Helvetica, Arial, sans-serif",
+    "-Efontsize=10",
+    "-Efontname=Helvetica Neue, Helvetica, Arial, sans-serif",
+    "-Gfontsize=10",
+    "-Gfontname=Helvetica Neue, Helvetica, Arial, sans-serif",
+]
+
 # Add any paths that contain custom static files (such as style sheets) here,
 # relative to this directory. They are copied after the builtin static files,
 # so a file named "default.css" will overwrite the builtin "default.css".
 # html_static_path = ["_static"]
 
-# Render inheritance diagrams in SVG
-graphviz_output_format = "svg"
-
-graphviz_dot_args = [
-    '-Nfontsize=10',
-    '-Nfontname=Helvetica Neue, Helvetica, Arial, sans-serif',
-    '-Efontsize=10',
-    '-Efontname=Helvetica Neue, Helvetica, Arial, sans-serif',
-    '-Gfontsize=10',
-    '-Gfontname=Helvetica Neue, Helvetica, Arial, sans-serif'
-]
+# By default, when rendering docstrings for classes, sphinx.ext.autodoc will
+# make docs with the class-level docstring and the class-method docstrings,
+# but not the __init__ docstring, which often contains the parameters to
+# class constructors across the scientific Python ecosystem. The option below
+# will append the __init__ docstring to the class-level docstring when rendering
+# the docs. For more options, see:
+# https://www.sphinx-doc.org/en/master/usage/extensions/autodoc.html#confval-autoclass_content
+autoclass_content = "both"
 
 # -- Sphinx Gallery ------------------------------------------------------------
 
