@@ -1,15 +1,9 @@
-import numpy as np
 
 import astropy.units as u
 import astropy.wcs.utils
-from astropy.coordinates import (
-    ITRS,
-    BaseCoordinateFrame,
-    CartesianRepresentation,
-    SkyCoord,
-    SphericalRepresentation,
-)
+from astropy.coordinates import BaseCoordinateFrame, SkyCoord
 from astropy.wcs import WCS
+from astropy.wcs.utils import obsgeo_to_frame
 
 from sunpy import log
 from .frames import (
@@ -22,59 +16,6 @@ from .frames import (
 
 __all__ = ['solar_wcs_frame_mapping', 'solar_frame_to_wcs_mapping']
 
-try:
-    # TODO: Remove vendored version after Astropy 5.0
-    from astropy.wcs.utils import obsgeo_to_frame
-except ImportError:
-    def obsgeo_to_frame(obsgeo, obstime):
-        """
-        Convert a WCS obsgeo property into an `~builtin_frames.ITRS` coordinate frame.
-
-        Parameters
-        ----------
-        obsgeo : array-like
-            A shape ``(6, )`` array representing ``OBSGEO-[XYZ], OBSGEO-[BLH]`` as
-            returned by ``WCS.wcs.obsgeo``.
-        obstime : time-like
-            The time associated with the coordinate, will be passed to
-            `~.builtin_frames.ITRS` as the obstime keyword.
-
-        Returns
-        -------
-        `~.builtin_frames.ITRS`
-            An `~.builtin_frames.ITRS` coordinate frame
-            representing the coordinates.
-
-        Notes
-        -----
-        The obsgeo array as accessed in a `.WCS` object is a length 6 numpy array
-        where the first three elements are the coordinate in a cartesian
-        representation and the second 3 are the coordinate in a spherical
-        representation.
-
-        This function priorities reading the cartesian coordinates, and will only
-        read the spherical coordinates if the cartesian coordinates are either all
-        zero or any of the cartesian coordinates are non-finite.
-
-        In the case where both the spherical and cartesian coordinates have some
-        non-finite values the spherical coordinates will be returned with the
-        non-finite values included.
-
-        """
-        if obsgeo is None or len(obsgeo) != 6 or np.all(np.array(obsgeo) == 0) or np.all(~np.isfinite(obsgeo)):
-            raise ValueError(f"Can not parse the 'obsgeo' location ({obsgeo}). "
-                             "obsgeo should be a length 6 non-zero, finite numpy array")
-
-        # If the cartesian coords are zero or have NaNs in them use the spherical ones
-        if np.all(obsgeo[:3] == 0) or np.any(~np.isfinite(obsgeo[:3])):
-            data = SphericalRepresentation(*(obsgeo[3:] * (u.deg, u.deg, u.m)))
-
-        # Otherwise we assume the cartesian ones are valid
-        else:
-            data = CartesianRepresentation(*obsgeo[:3] * u.m)
-
-        return ITRS(data, obstime=obstime)
-
 
 def solar_wcs_frame_mapping(wcs):
     """
@@ -93,7 +34,7 @@ def solar_wcs_frame_mapping(wcs):
     if hasattr(wcs, "coordinate_frame"):
         return wcs.coordinate_frame
 
-    dateobs = wcs.wcs.dateavg or wcs.wcs.dateobs or None
+    dateobs = wcs.wcs.dateavg or wcs.wcs.dateobs or wcs.wcs.datebeg or wcs.wcs.dateend or None
 
     # Get observer coordinate from the WCS auxiliary information
     # Note: the order of the entries is important, as it determines which set
